@@ -658,10 +658,7 @@ class ChooseLibraryAction(InterfaceAction):
 
         d = DBCheck(self.gui, db)
         try:
-            d.start()
-            from calibre.gui2.widgets import BusyCursor
-            with BusyCursor():
-                d.exec()
+            d.exec()
             try:
                 m.close()
             except Exception:
@@ -689,9 +686,12 @@ class ChooseLibraryAction(InterfaceAction):
             d = CheckLibraryDialog(self.gui, m.db)
 
             if not d.do_exec():
-                info_dialog(self.gui, _('No problems found'),
-                        _('The files in your library match the information '
-                        'in the database.'), show=True)
+                if question_dialog(self.gui, _('No problems found'),
+                        _('The files in your library match the information in the database.\n\n'
+                          "Choose 'Open dialog' to change settings and run the check again."),
+                        yes_text=_('Open dialog'), yes_icon='gear.png', no_icon='ok.png',
+                        no_text=_('Finished')):
+                    d.exec()
         finally:
             self.gui.status_bar.clear_message()
 
