@@ -45,22 +45,22 @@ class ShareConnMenu(QMenu):  # {{{
     def __init__(self, parent=None):
         QMenu.__init__(self, parent)
         self.ip_text = ''
-        mitem = self.addAction(QIcon(I('devices/folder.png')), _('Connect to folder'))
+        mitem = self.addAction(QIcon.ic('devices/folder.png'), _('Connect to folder'))
         mitem.setEnabled(True)
         connect_lambda(mitem.triggered, self, lambda self: self.connect_to_folder.emit())
         self.connect_to_folder_action = mitem
 
         self.addSeparator()
         self.toggle_server_action = \
-            self.addAction(QIcon(I('network-server.png')),
+            self.addAction(QIcon.ic('network-server.png'),
             _('Start Content server'))
         connect_lambda(self.toggle_server_action.triggered, self, lambda self: self.toggle_server.emit())
         self.open_server_in_browser_action = self.addAction(
-            QIcon(I('forward.png')), _("Visit Content server in browser"))
+            QIcon.ic('forward.png'), _("Visit Content server in browser"))
         connect_lambda(self.open_server_in_browser_action.triggered, self, lambda self: open_in_browser())
         self.open_server_in_browser_action.setVisible(False)
         self.control_smartdevice_action = \
-            self.addAction(QIcon(I('dot_red.png')),
+            self.addAction(QIcon.ic('dot_red.png'),
             self.DEVICE_MSGS[0])
         connect_lambda(self.control_smartdevice_action.triggered, self, lambda self: self.control_smartdevice.emit())
         self.addSeparator()
@@ -126,9 +126,9 @@ class ShareConnMenu(QMenu):  # {{{
                 subject = opts.subjects.get(account, '')
                 alias = opts.aliases.get(account, '')
                 dest = 'mail:'+account+';'+formats+';'+subject
-                action1 = DeviceAction(dest, False, False, I('mail.png'),
+                action1 = DeviceAction(dest, False, False, 'mail.png',
                         alias or account)
-                action2 = DeviceAction(dest, True, False, I('mail.png'),
+                action2 = DeviceAction(dest, True, False, 'mail.png',
                         (alias or account) + ' ' + _('(delete from library)'))
                 self.email_to_menu.addAction(action1)
                 self.email_to_and_delete_menu.addAction(action2)
@@ -136,22 +136,22 @@ class ShareConnMenu(QMenu):  # {{{
                 self.memory.append(action2)
                 if default:
                     ac = DeviceAction(dest, False, False,
-                            I('mail.png'), _('Email to') + ' ' +(alias or
+                            'mail.png', _('Email to') + ' ' +(alias or
                                 account))
                     self.addAction(ac)
                     self.email_actions.append(ac)
                     ac.a_s.connect(sync_menu.action_triggered)
                 action1.a_s.connect(sync_menu.action_triggered)
                 action2.a_s.connect(sync_menu.action_triggered)
-            action1 = DeviceAction('choosemail:', False, False, I('mail.png'),
+            action1 = DeviceAction('choosemail:', False, False, 'mail.png',
                     _('Select recipients'))
-            action2 = DeviceAction('choosemail:', True, False, I('mail.png'),
+            action2 = DeviceAction('choosemail:', True, False, 'mail.png',
                     _('Select recipients') + ' ' + _('(delete from library)'))
             self.email_to_menu.addAction(action1)
             self.email_to_and_delete_menu.addAction(action2)
             self.memory.append(action1)
             self.memory.append(action2)
-            tac1 = DeviceAction('choosemail:', False, False, I('mail.png'),
+            tac1 = DeviceAction('choosemail:', False, False, 'mail.png',
                     _('Email to selected recipients...'))
             self.addAction(tac1)
             tac1.a_s.connect(sync_menu.action_triggered)
@@ -228,10 +228,10 @@ class ConnectShareAction(InterfaceAction):
         self.share_conn_menu.server_state_changed(running)
         if running:
             self.content_server_is_running = True
-            self.qaction.setIcon(QIcon(I('connect_share_on.png')))
+            self.qaction.setIcon(QIcon.ic('connect_share_on.png'))
         else:
             self.content_server_is_running = False
-            self.qaction.setIcon(QIcon(I('connect_share.png')))
+            self.qaction.setIcon(QIcon.ic('connect_share.png'))
 
     def toggle_content_server(self):
         if self.gui.content_server is None:
@@ -304,5 +304,5 @@ class ConnectShareAction(InterfaceAction):
 
         icon = 'green' if running else 'red'
         ac = self.share_conn_menu.control_smartdevice_action
-        ac.setIcon(QIcon(I('dot_%s.png'%icon)))
+        ac.setIcon(QIcon.ic('dot_%s.png'%icon))
         ac.setText(text)
