@@ -5,7 +5,7 @@
 import os
 import re
 from collections import namedtuple
-from functools import partial
+from functools import partial, lru_cache
 from qt.core import (
     QAction, QApplication, QClipboard, QColor, QDialog, QEasingCurve, QIcon,
     QKeySequence, QMenu, QMimeData, QPainter, QPen, QPixmap, QSplitter,
@@ -88,6 +88,8 @@ def copy_all(text_browser):
     from calibre.utils.html2text import html2text
     simplified_html = etree.tostring(root, encoding='unicode')
     txt = html2text(simplified_html, single_line_break=True).strip()
+    if iswindows:
+        txt = '\r\n'.join(txt.splitlines())
     # print(simplified_html)
     # print(txt)
     md.setText(txt)
@@ -195,6 +197,11 @@ def init_find_in_grouped_search(menu, field, value, book_info):
                     '{}:"={}"'.format(g, value.replace('"', r'\"')), ''))
 
 
+@lru_cache(maxsize=2)
+def comments_pat():
+    return re.compile(r'<!--.*?-->', re.DOTALL)
+
+
 def render_html(mi, vertical, widget, all_fields=False, render_data_func=None, pref_name='book_display_fields'):  # {{{
     from calibre.gui2.ui import get_gui
     func = render_data_func or partial(render_data,
@@ -225,6 +232,8 @@ def render_html(mi, vertical, widget, all_fields=False, render_data_func=None, p
     comments = ''
     if comment_fields:
         comments = '\n'.join('<div>%s</div>' % x for x in comment_fields)
+        # Comments cause issues with rendering in QTextBrowser
+        comments = comments_pat().sub('', comments)
     right_pane = comments
 
     if vertical:
