@@ -4,7 +4,7 @@ __docformat__ = 'restructuredtext en'
 
 import shutil
 
-from qt.core import QModelIndex, QDialog, QApplication, QDialogButtonBox
+from qt.core import QModelIndex, QDialog, QDialogButtonBox
 
 from calibre.gui2.convert.single import Config, GroupModel, gprefs
 from calibre.gui2.convert.look_and_feel import LookAndFeelWidget
@@ -18,7 +18,6 @@ from calibre.ebooks.conversion.plumber import Plumber
 from calibre.ebooks.conversion.config import sort_formats_by_preference, get_output_formats
 from calibre.utils.config import prefs
 from calibre.utils.logging import Log
-from polyglot.builtins import native_string_type
 
 
 class BulkConfig(Config):
@@ -47,7 +46,7 @@ class BulkConfig(Config):
             'values saved in a previous conversion (if they exist) instead '
             'of using the defaults specified in the Preferences'))
 
-        self.output_formats.currentIndexChanged[native_string_type].connect(self.setup_pipeline)
+        self.output_formats.currentIndexChanged.connect(self.setup_pipeline)
         self.groups.setSpacing(5)
         self.groups.activated[(QModelIndex)].connect(self.show_pane)
         self.groups.clicked[(QModelIndex)].connect(self.show_pane)
@@ -62,11 +61,7 @@ class BulkConfig(Config):
                 'settings.'))
             o.setChecked(False)
 
-        geom = gprefs.get('convert_bulk_dialog_geom', None)
-        if geom:
-            QApplication.instance().safe_restore_geometry(self, geom)
-        else:
-            self.resize(self.sizeHint())
+        self.restore_geometry(gprefs, 'convert_bulk_dialog_geom')
 
     def setup_pipeline(self, *args):
         oidx = self.groups.currentIndex().row()
@@ -141,6 +136,5 @@ class BulkConfig(Config):
 
     def done(self, r):
         if self.isVisible():
-            gprefs['convert_bulk_dialog_geom'] = \
-                bytearray(self.saveGeometry())
+            self.save_geometry(gprefs, 'convert_bulk_dialog_geom')
         return QDialog.done(self, r)
