@@ -13,7 +13,7 @@ class PluginWidget(Widget, Ui_Form):
     TITLE = _('TXT output')
     HELP = _('Options specific to')+' TXT '+_('output')
     COMMIT_NAME = 'txt_output'
-    ICON = I('mimetypes/txt.png')
+    ICON = 'mimetypes/txt.png'
 
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
         Widget.__init__(self, parent, OPTIONS['output']['txt'])
