@@ -6,8 +6,8 @@ import textwrap
 from qt.core import (
     QAction, QApplication, QBrush, QCheckBox, QDialog, QGridLayout,
     QHBoxLayout, QIcon, QKeySequence, QLabel, QListView, QModelIndex, QPalette,
-    QPixmap, QPushButton, QShortcut, QSize, QSplitter, Qt, QTimer, QToolButton,
-    QVBoxLayout, QWidget, pyqtSignal, QDialogButtonBox
+    QPixmap, QPushButton, QShortcut, QSize, Qt, QTimer, QToolButton,
+    QVBoxLayout, QWidget, pyqtSignal, QDialogButtonBox, QSplitter
 )
 
 from calibre import fit_image
@@ -75,11 +75,11 @@ class Configure(Dialog):
         v = QVBoxLayout()
         self.mub = b = QToolButton(self)
         connect_lambda(b.clicked, self, lambda self: move_field_up(fdo, self.model))
-        b.setIcon(QIcon(I('arrow-up.png')))
+        b.setIcon(QIcon.ic('arrow-up.png'))
         b.setToolTip(_('Move the selected field up'))
         v.addWidget(b), v.addStretch(10)
         self.mud = b = QToolButton(self)
-        b.setIcon(QIcon(I('arrow-down.png')))
+        b.setIcon(QIcon.ic('arrow-down.png'))
         b.setToolTip(_('Move the selected field down'))
         connect_lambda(b.clicked, self, lambda self: move_field_down(fdo, self.model))
         v.addWidget(b)
@@ -176,10 +176,10 @@ class BookInfo(QDialog):
             _('Configure this view'), _('Configure')))
         self.clabel.linkActivated.connect(self.configure)
         hl.addWidget(self.clabel)
-        self.previous_button = QPushButton(QIcon(I('previous.png')), _('&Previous'), self)
+        self.previous_button = QPushButton(QIcon.ic('previous.png'), _('&Previous'), self)
         self.previous_button.clicked.connect(self.previous)
         l2.addWidget(self.previous_button, l2.rowCount(), 0)
-        self.next_button = QPushButton(QIcon(I('next.png')), _('&Next'), self)
+        self.next_button = QPushButton(QIcon.ic('next.png'), _('&Next'), self)
         self.next_button.clicked.connect(self.next)
         l2.addWidget(self.next_button, l2.rowCount() - 1, 1)
 
@@ -198,17 +198,11 @@ class BookInfo(QDialog):
         self.previous_button.setToolTip(_('Previous [%s]')%
                 str(self.ps.key().toString(QKeySequence.SequenceFormat.NativeText)))
 
-        geom = self.screen().availableSize()
-        screen_height = geom.height() - 100
-        screen_width = geom.width() - 100
-        self.resize(max(int(screen_width/2), 700), screen_height)
-        saved_layout = gprefs.get('book_info_dialog_layout', None)
-        if saved_layout is not None:
-            try:
-                QApplication.instance().safe_restore_geometry(self, saved_layout[0])
-                self.splitter.restoreState(saved_layout[1])
-            except Exception:
-                pass
+        self.restore_geometry(gprefs, 'book_info_dialog_geometry')
+        try:
+            self.splitter.restoreState(gprefs.get('book_info_dialog_splitter_state'))
+        except Exception:
+            pass
         ema = get_gui().iactions['Edit Metadata'].menuless_qaction
         a = self.ema = QAction('edit metadata', self)
         a.setShortcut(ema.shortcut())
@@ -220,6 +214,15 @@ class BookInfo(QDialog):
         a.triggered.connect(self.view_book)
         self.addAction(a)
 
+    def sizeHint(self):
+        try:
+            geom = self.screen().availableSize()
+            screen_height = geom.height() - 100
+            screen_width = geom.width() - 100
+            return QSize(max(int(screen_width/2), 700), screen_height)
+        except Exception:
+            return QSize(800, 600)
+
     def view_book(self):
         if self.current_row is not None:
             book_id = self.view.model().id(self.current_row)
@@ -228,7 +231,9 @@ class BookInfo(QDialog):
     def edit_metadata(self):
         if self.current_row is not None:
             book_id = self.view.model().id(self.current_row)
-            get_gui().iactions['Edit Metadata'].edit_metadata_for([self.current_row], [book_id], bulk=False)
+            em = get_gui().iactions['Edit Metadata']
+            with em.different_parent(self):
+                em.edit_metadata_for([self.current_row], [book_id], bulk=False)
 
     def configure(self):
         d = Configure(get_gui().current_db, self)
@@ -243,8 +248,8 @@ class BookInfo(QDialog):
         self.link_delegate(link)
 
     def done(self, r):
-        saved_layout = (bytearray(self.saveGeometry()), bytearray(self.splitter.saveState()))
-        gprefs.set('book_info_dialog_layout', saved_layout)
+        self.save_geometry(gprefs, 'book_info_dialog_geometry')
+        gprefs['book_info_dialog_splitter_state'] = bytearray(self.splitter.saveState())
         ret = QDialog.done(self, r)
         self.view.model().new_bookdisplay_data.disconnect(self.slave)
         self.view = self.link_delegate = self.gui = None
