@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:fdm=marker:ai
 
 
 __license__   = 'GPL v3'
@@ -27,7 +26,7 @@ class DuplicatesQuestion(QDialog):
         if len(duplicates) > 1:
             t = '%d %s' % (len(duplicates), t)
         self.setWindowTitle(t)
-        self.i = i = QIcon(I('dialog_question.png'))
+        self.i = i = QIcon.ic('dialog_question.png')
         self.setWindowIcon(i)
 
         self.l1 = l1 = QLabel()
@@ -52,18 +51,16 @@ class DuplicatesQuestion(QDialog):
         l.addWidget(bb, 2, 0, 1, 2)
         l.setColumnStretch(1, 10)
         self.ab = ab = bb.addButton(_('Select &all'), QDialogButtonBox.ButtonRole.ActionRole)
-        ab.clicked.connect(self.select_all), ab.setIcon(QIcon(I('plus.png')))
+        ab.clicked.connect(self.select_all), ab.setIcon(QIcon.ic('plus.png'))
         self.nb = ab = bb.addButton(_('Select &none'), QDialogButtonBox.ButtonRole.ActionRole)
-        ab.clicked.connect(self.select_none), ab.setIcon(QIcon(I('minus.png')))
+        ab.clicked.connect(self.select_none), ab.setIcon(QIcon.ic('minus.png'))
         self.cb = cb = bb.addButton(_('&Copy to clipboard'), QDialogButtonBox.ButtonRole.ActionRole)
-        cb.setIcon(QIcon(I('edit-copy.png')))
+        cb.setIcon(QIcon.ic('edit-copy.png'))
         cb.clicked.connect(self.copy_to_clipboard)
 
         self.resize(self.sizeHint())
-        geom = gprefs.get('duplicates-question-dialog-geometry', None)
-        if geom is not None:
-            QApplication.instance().safe_restore_geometry(self, geom)
-        self.exec_()
+        self.restore_geometry(gprefs, 'duplicates-question-dialog-geometry')
+        self.exec()
 
     def copy_to_clipboard(self):
         QApplication.clipboard().setText(self.as_text)
@@ -88,7 +85,7 @@ class DuplicatesQuestion(QDialog):
         QDialog.accept(self)
 
     def save_geometry(self):
-        gprefs.set('duplicates-question-dialog-geometry', bytearray(self.saveGeometry()))
+        super().save_geometry(gprefs, 'duplicates-question-dialog-geometry')
 
     def process_duplicates(self, db, duplicates):
         ta = _('%(title)s by %(author)s [%(formats)s]')
@@ -150,7 +147,7 @@ class DuplicatesQuestion(QDialog):
         for i in range(self.dup_list.topLevelItemCount()):
             x = self.dup_list.topLevelItem(i)
             check = '✓' if x.checkState(0) == Qt.CheckState.Checked else '✗'
-            title = '%s %s' % (check, str(x.text(0)))
+            title = f'{check} {str(x.text(0))}'
             dups = []
             for child in (x.child(j) for j in range(x.childCount())):
                 dups.append('\t' + str(child.text(0)))
