@@ -542,10 +542,7 @@ class Quickview(QDialog, Ui_Quickview):
         self.books_table.setRowCount(0)
 
         mi = self.db.new_api.get_proxy_metadata(book_id)
-        vals = mi.get(key, None)
-        if self.fm[key]['datatype'] == 'composite' and self.fm[key]['is_multiple']:
-            sep = self.fm[key]['is_multiple'].get('cache_to_list', ',')
-            vals = [v.strip() for v in vals.split(sep) if v.strip()]
+        vals = self.db.new_api.split_if_is_multiple_composite(key, mi.get(key, None))
         try:
             # Check if we are in the GridView and there are no values for the
             # selected column. In this case switch the column to 'authors'
