@@ -2,8 +2,7 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
 from qt.core import (
-    QAbstractItemView, QApplication, QDialog, QSortFilterProxyModel,
-    QStringListModel, Qt
+    QAbstractItemView, QDialog, QSortFilterProxyModel, QStringListModel, Qt,
 )
 
 from calibre.constants import islinux
@@ -103,15 +102,16 @@ class TagEditor(QDialog, Ui_TagEditor):
             connect_lambda(ibox.textChanged, self, lambda self: self.edit_box_changed(self.sender().objectName()))
         getattr(self, gprefs.get('tag_editor_last_filter', 'add_tag_input')).setFocus()
 
+        self.available_tags.setEditTriggers(QAbstractItemView.EditTrigger.NoEditTriggers)
+        self.applied_tags.setEditTriggers(QAbstractItemView.EditTrigger.NoEditTriggers)
         if islinux:
             self.available_tags.doubleClicked.connect(self.apply_tags)
+            self.applied_tags.doubleClicked.connect(self.unapply_tags)
         else:
             self.available_tags.activated.connect(self.apply_tags)
-        self.applied_tags.activated.connect(self.unapply_tags)
+            self.applied_tags.activated.connect(self.unapply_tags)
 
-        geom = gprefs.get('tag_editor_geometry', None)
-        if geom is not None:
-            QApplication.instance().safe_restore_geometry(self, geom)
+        self.restore_geometry(gprefs, 'tag_editor_geometry')
 
     def edit_box_changed(self, which):
         gprefs['tag_editor_last_filter'] = which
@@ -121,7 +121,7 @@ class TagEditor(QDialog, Ui_TagEditor):
         row_indices = list(self.available_tags.selectionModel().selectedRows())
 
         if not row_indices:
-            error_dialog(self, 'No tags selected', 'You must select at least one tag from the list of Available tags.').exec()
+            error_dialog(self, _('No tags selected'), _('You must select at least one tag from the list of Available tags.')).exec()
             return
         if not confirm(
             _('Deleting tags is done immediately and there is no undo.'),
@@ -213,6 +213,8 @@ class TagEditor(QDialog, Ui_TagEditor):
         collection.model().setFilterFixedString(filter_value or '')
 
     def accept(self):
+        if self.add_tag_input.text().strip():
+            self.add_tag()
         self.tags = self._get_applied_tags_box_contents()
         self.save_state()
         return QDialog.accept(self)
@@ -222,7 +224,7 @@ class TagEditor(QDialog, Ui_TagEditor):
         return QDialog.reject(self)
 
     def save_state(self):
-        gprefs['tag_editor_geometry'] = bytearray(self.saveGeometry())
+        self.save_geometry(gprefs, 'tag_editor_geometry')
 
 
 if __name__ == '__main__':
