@@ -10,10 +10,10 @@ import os
 from datetime import datetime
 from functools import partial
 from qt.core import (
-    QApplication, QDialog, QDialogButtonBox, QFrame, QGridLayout, QGroupBox,
-    QHBoxLayout, QIcon, QInputDialog, QKeySequence, QMenu, QPushButton, QScrollArea,
-    QShortcut, QSize, QSizePolicy, QSpacerItem, QSplitter, Qt, QTabWidget,
-    QToolButton, QVBoxLayout, QWidget, pyqtSignal
+    QDialog, QDialogButtonBox, QFrame, QGridLayout, QGroupBox, QHBoxLayout, QIcon,
+    QInputDialog, QKeySequence, QMenu, QPushButton, QScrollArea, QShortcut, QSize,
+    QSizePolicy, QSpacerItem, QSplitter, Qt, QTabWidget, QToolButton, QVBoxLayout,
+    QWidget, pyqtSignal,
 )
 
 from calibre.constants import ismacos
@@ -26,7 +26,7 @@ from calibre.gui2.metadata.basic_widgets import (
     AuthorsEdit, AuthorSortEdit, BuddyLabel, CommentsEdit, Cover, DateEdit,
     FormatsManager, IdentifiersEdit, LanguagesEdit, PubdateEdit, PublisherEdit,
     RatingEdit, RightClickButton, SeriesEdit, SeriesIndexEdit, TagsEdit, TitleEdit,
-    TitleSortEdit, show_locked_file_error
+    TitleSortEdit, show_locked_file_error,
 )
 from calibre.gui2.metadata.single_download import FullFetch
 from calibre.gui2.widgets2 import CenteredToolButton
@@ -120,11 +120,7 @@ class MetadataSingleDialogBase(QDialog):
         self.comments_edit_state_at_apply = {self.comments:None}
 
         self.do_layout()
-        geom = gprefs.get('metasingle_window_geometry3', None)
-        if geom is not None:
-            QApplication.instance().safe_restore_geometry(self, bytes(geom))
-        else:
-            self.resize(self.sizeHint())
+        self.restore_geometry(gprefs, 'metasingle_window_geometry3')
         self.restore_widget_settings()
     # }}}
 
@@ -650,7 +646,7 @@ class MetadataSingleDialogBase(QDialog):
 
     def save_state(self):
         try:
-            gprefs['metasingle_window_geometry3'] = bytearray(self.saveGeometry())
+            self.save_geometry(gprefs, 'metasingle_window_geometry3')
             self.save_widget_settings()
         except:
             # Weird failure, see https://bugs.launchpad.net/bugs/995271
@@ -741,7 +737,7 @@ class Splitter(QSplitter):
 
     def resizeEvent(self, ev):
         self.frame_resized.emit(ev)
-        return QSplitter.resizeEvent(self, ev)
+        return super().resizeEvent(ev)
 
 
 class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
@@ -1043,7 +1039,7 @@ class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
             QSizePolicy.Policy.Expanding))
         wgl.addWidget(self.formats_manager)
 
-        self.splitter = QSplitter(Qt.Orientation.Horizontal, tab1)
+        self.splitter = Splitter(Qt.Orientation.Horizontal, tab1)
         tab1.l.addWidget(self.splitter)
         self.splitter.addWidget(self.cover)
         self.splitter.addWidget(wsp)
@@ -1211,7 +1207,7 @@ class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
         cover_layout.addLayout(hl)
         sto(self.cover.buttons[-2], self.cover.buttons[-1])
         # Splitter for both cover & formats boxes
-        self.cover_and_formats = cover_and_formats = QSplitter(Qt.Orientation.Vertical)
+        self.cover_and_formats = cover_and_formats = Splitter(Qt.Orientation.Vertical)
         # Put a very small margin on the left so that the word "Cover" doesn't
         # touch the splitter
         cover_and_formats.setContentsMargins(1, 0, 0, 0)
