@@ -60,10 +60,10 @@ class TextureChooser(QDialog):
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         b = self.add_button = bb.addButton(_('Add texture'), QDialogButtonBox.ButtonRole.ActionRole)
-        b.setIcon(QIcon(I('plus.png')))
+        b.setIcon(QIcon.ic('plus.png'))
         b.clicked.connect(self.add_texture)
         b = self.remove_button = bb.addButton(_('Remove texture'), QDialogButtonBox.ButtonRole.ActionRole)
-        b.setIcon(QIcon(I('minus.png')))
+        b.setIcon(QIcon.ic('minus.png'))
         b.clicked.connect(self.remove_texture)
         l.addWidget(bb)
 
