@@ -7,7 +7,7 @@ __copyright__ = '2011, John Schember <john@nachtimwald.com>'
 __docformat__ = 'restructuredtext en'
 
 
-from qt.core import (Qt, QDialog, QIcon, QComboBox, QApplication)
+from qt.core import Qt, QDialog, QIcon, QComboBox
 
 from calibre.gui2.store.stores.mobileread.adv_search_builder import AdvSearchBuilderDialog
 from calibre.gui2.store.stores.mobileread.models import BooksModel
@@ -56,10 +56,7 @@ class MobileReadStoreDialog(QDialog, Ui_Dialog):
             self.search_query.setText(adv.search_string())
 
     def restore_state(self):
-        geometry = self.plugin.config.get('dialog_geometry', None)
-        if geometry:
-            QApplication.instance().safe_restore_geometry(self, geometry)
-
+        self.restore_geometry(self.plugin.config, 'dialog_geometry')
         results_cwidth = self.plugin.config.get('dialog_results_view_column_width')
         if results_cwidth:
             for i, x in enumerate(results_cwidth):
@@ -76,7 +73,7 @@ class MobileReadStoreDialog(QDialog, Ui_Dialog):
         self.results_view.header().setSortIndicator(self.results_view.model().sort_col, self.results_view.model().sort_order)
 
     def save_state(self):
-        self.plugin.config['dialog_geometry'] = bytearray(self.saveGeometry())
+        self.save_geometry(self.plugin.config, 'dialog_geometry')
         self.plugin.config['dialog_results_view_column_width'] = [self.results_view.columnWidth(i) for i in range(self.results_view.model().columnCount())]
         self.plugin.config['dialog_sort_col'] = self.results_view.model().sort_col
         self.plugin.config['dialog_sort_order'] = self.results_view.model().sort_order
