@@ -118,7 +118,7 @@ class DebugOutput(Dialog):
         self.bb.setStandardButtons(QDialogButtonBox.StandardButton.Close)
         self.cb = b = self.bb.addButton(_('&Copy to clipboard'), QDialogButtonBox.ButtonRole.ActionRole)
         b.clicked.connect(self.copy_to_clipboard)
-        b.setIcon(QIcon(I('edit-copy.png')))
+        b.setIcon(QIcon.ic('edit-copy.png'))
 
     def show_log(self, name, text):
         if isinstance(text, bytes):
