@@ -53,12 +53,10 @@ class TOCView(QTreeView):
         self.gesture_manager = GestureManager(self)
 
     def viewportEvent(self, ev):
-        try:
+        if hasattr(self, 'gesture_manager'):
             ret = self.gesture_manager.handle_event(ev)
-        except AttributeError:
-            ret = None
-        if ret is not None:
-            return ret
+            if ret is not None:
+                return ret
         return super().viewportEvent(ev)
 
     def setModel(self, model):
