@@ -10,7 +10,7 @@ from qt.core import (QIcon, QFont, QLabel, QListWidget, QAction, QEvent,
         QCursor, QColor, QWidget, QPixmap, QSplitterHandle, QToolButton,
         Qt, pyqtSignal, QSize, QSplitter, QPainter, QPageSize, QPrinter,
         QLineEdit, QComboBox, QPen, QGraphicsScene, QMenu, QStringListModel, QKeySequence,
-        QCompleter, QTimer, QRect, QGraphicsView, QPagedPaintDevice, QPalette, QClipboard)
+        QCompleter, QTimer, QRect, QGraphicsView, QPalette, QClipboard)
 
 from calibre.constants import iswindows, ismacos
 from calibre.gui2 import (error_dialog, pixmap_to_data, gprefs,
@@ -490,27 +490,36 @@ class LineEditECM:  # {{{
         menu = self.createStandardContextMenu()
         menu.addSeparator()
         self.create_change_case_menu(menu)
+        if callable(getattr(self, 'add_items_to_context_menu', None)):
+            menu = self.add_items_to_context_menu(self, menu)
         menu.exec(event.globalPos())
 
+    def modify_case_operation(self, func):
+        has_selection = self.hasSelectedText()
+        text = self.selectedText() if has_selection else self.text()
+        ntext = func(text)
+        if ntext != text:
+            self.insert(ntext) if has_selection else self.setText(ntext)
+
     def upper_case(self):
         from calibre.utils.icu import upper
-        self.setText(upper(str(self.text())))
+        self.modify_case_operation(upper)
 
     def lower_case(self):
         from calibre.utils.icu import lower
-        self.setText(lower(str(self.text())))
+        self.modify_case_operation(lower)
 
     def swap_case(self):
         from calibre.utils.icu import swapcase
-        self.setText(swapcase(str(self.text())))
+        self.modify_case_operation(swapcase)
 
     def title_case(self):
         from calibre.utils.titlecase import titlecase
-        self.setText(titlecase(str(self.text())))
+        self.modify_case_operation(titlecase)
 
     def capitalize(self):
         from calibre.utils.icu import capitalize
-        self.setText(capitalize(str(self.text())))
+        self.modify_case_operation(capitalize)
 
 # }}}
 
@@ -740,7 +749,7 @@ class ComboBoxWithHelp(QComboBox):  # {{{
 
     def __init__(self, parent=None):
         QComboBox.__init__(self, parent)
-        self.currentIndexChanged[int].connect(self.index_changed)
+        self.currentIndexChanged.connect(self.index_changed)
         self.help_text = ''
         self.state_set = False
 
@@ -860,7 +869,7 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
                 r"|\b[+-]?[0-9]+(?:\.[0-9]+)?(?:[eE][+-]?[0-9]+)?\b"),
                 "number")
         a(re.compile(
-                r"\bPyQt5\b|\bQt?[A-Z][a-z]\w+\b"), "pyqt")
+                r"\bPyQt6\b|\bQt?[A-Z][a-z]\w+\b"), "pyqt")
         a(re.compile(r"\b@\w+\b"), "decorator")
         stringRe = re.compile(r"""(?:'[^']*?'|"[^"]*?")""")
         a(stringRe, "string")
@@ -873,7 +882,7 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
     @classmethod
     def initializeFormats(cls):
         baseFormat = QTextCharFormat()
-        baseFormat.setFontFamily('monospace')
+        baseFormat.setFontFamilies(['monospace'])
         p = QApplication.instance().palette()
         for name, color, bold, italic in (
                 ("normal", None, False, False),
@@ -971,13 +980,12 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
 
 # Splitter {{{
 
-
 class SplitterHandle(QSplitterHandle):
 
     double_clicked = pyqtSignal(object)
 
     def __init__(self, orientation, splitter):
-        QSplitterHandle.__init__(self, orientation, splitter)
+        super().__init__(orientation, splitter)
         splitter.splitterMoved.connect(self.splitter_moved,
                 type=Qt.ConnectionType.QueuedConnection)
         self.double_clicked.connect(splitter.double_clicked,
@@ -1000,7 +1008,7 @@ class LayoutButton(QToolButton):
     def __init__(self, icon, text, splitter=None, parent=None, shortcut=None):
         QToolButton.__init__(self, parent)
         self.label = text
-        self.setIcon(QIcon(icon))
+        self.setIcon(QIcon.ic(icon))
         self.setCheckable(True)
         self.icname = os.path.basename(icon).rpartition('.')[0]
 
@@ -1066,7 +1074,7 @@ class Splitter(QSplitter):
             initial_side_size=120, connect_button=True,
             orientation=Qt.Orientation.Horizontal, side_index=0, parent=None,
             shortcut=None, hide_handle_on_single_panel=True):
-        QSplitter.__init__(self, parent)
+        super().__init__(parent)
         self.reapply_sizes.connect(self.setSizes, type=Qt.ConnectionType.QueuedConnection)
         self.hide_handle_on_single_panel = hide_handle_on_single_panel
         if hide_handle_on_single_panel:
@@ -1090,7 +1098,7 @@ class Splitter(QSplitter):
             self.button.clicked.connect(self.double_clicked)
 
         if shortcut is not None:
-            self.action_toggle = QAction(QIcon(icon), _('Toggle') + ' ' + label,
+            self.action_toggle = QAction(QIcon.ic(icon), _('Toggle') + ' ' + label,
                     self)
             self.action_toggle.changed.connect(self.update_shortcut)
             self.action_toggle.triggered.connect(self.toggle_triggered)
@@ -1180,7 +1188,7 @@ class Splitter(QSplitter):
 
     def do_resize(self, *args):
         orig = self.desired_side_size
-        QSplitter.resizeEvent(self, self._resize_ev)
+        super().resizeEvent(self._resize_ev)
         if orig > 20 and self.desired_show:
             c = 0
             while abs(self.side_index_size - orig) > 10 and c < 5:
@@ -1268,12 +1276,12 @@ class PaperSizes(QComboBox):  # {{{
             if iswindows or ismacos:
                 # On Linux, this can cause Qt to load the system cups plugin
                 # which can crash: https://bugs.launchpad.net/calibre/+bug/1861741
-                PaperSizes.system_default_paper_size = 'letter' if QPrinter().pageSize() == QPagedPaintDevice.PageSize.Letter else 'a4'
+                PaperSizes.system_default_paper_size = 'letter' if QPrinter().pageLayout().pageSize().id() == QPageSize.PageSizeId.Letter else 'a4'
         if not choices:
             from calibre.ebooks.conversion.plugins.pdf_output import PAPER_SIZES
             choices = PAPER_SIZES
         for a in sorted(choices, key=numeric_sort_key):
-            s = getattr(QPageSize, a.capitalize())
+            s = getattr(QPageSize.PageSizeId, a.capitalize())
             sz = QPageSize.definitionSize(s)
             unit = {QPageSize.Unit.Millimeter: 'mm', QPageSize.Unit.Inch: 'inch'}[QPageSize.definitionUnits(s)]
             name = f'{QPageSize.name(s)} ({sz.width():g} x {sz.height():g} {unit})'
@@ -1292,6 +1300,16 @@ class PaperSizes(QComboBox):  # {{{
 # }}}
 
 
+class BusyCursor:  # {{{
+
+    def __enter__(self):
+        QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
+
+    def __exit__(self, *args):
+        QApplication.restoreOverrideCursor()
+# }}}
+
+
 if __name__ == '__main__':
     from qt.core import QTextEdit
     app = QApplication([])
