@@ -9,6 +9,7 @@ import time, traceback, locale
 from itertools import repeat
 from datetime import timedelta
 from threading import Thread
+from contextlib import suppress
 
 from calibre.utils.config import tweaks, prefs
 from calibre.utils.date import parse_date, now, UNDEFINED_DATE, clean_date_for_sort
@@ -912,13 +913,12 @@ class ResultCache(SearchQueryParser):  # {{{
     def set_marked_ids(self, id_dict):
         '''
         ids in id_dict are "marked". They can be searched for by
-        using the search term ``marked:true``. Pass in an empty dictionary or
-        set to clear marked ids.
+        using the search term ``marked:true`` or ``marked:value``.
+        Pass in an empty dictionary or set to clear marked ids.
 
         :param id_dict: Either a dictionary mapping ids to values or a set
-        of ids. In the latter case, the value is set to 'true' for all ids. If
-        a mapping is provided, then the search can be used to search for
-        particular values: ``marked:value``
+        of ids. If a mapping is provided, then the search can be used to search
+        for particular values: ``marked:value``
         '''
         if not hasattr(id_dict, 'items'):
             # Simple list. Make it a dict of string 'true'
@@ -930,14 +930,13 @@ class ResultCache(SearchQueryParser):  # {{{
 
         # Set the values in the cache
         marked_col = self.FIELD_MAP['marked']
+        in_tag_browser_col = self.FIELD_MAP['in_tag_browser']
         for r in self.iterall():
-            r[marked_col] = None
+            r[marked_col] = r[in_tag_browser_col] = None
 
-        for id_, val in iteritems(self.marked_ids_dict):
-            try:
+        for id_, val in self.marked_ids_dict.items():
+            with suppress(Exception):
                 self._data[id_][marked_col] = val
-            except:
-                pass
 
     def get_marked(self, idx, index_is_id=True, default_value=None):
         id_ = idx if index_is_id else self[idx][0]
@@ -1057,7 +1056,7 @@ class ResultCache(SearchQueryParser):  # {{{
             if item is not None:
                 item.append(db.book_on_device_string(item[0]))
                 # Temp mark and series_sort columns
-                item.extend((None, None))
+                item.extend((None, None, None))
 
         marked_col = self.FIELD_MAP['marked']
         for id_,val in iteritems(self.marked_ids_dict):
@@ -1066,6 +1065,10 @@ class ResultCache(SearchQueryParser):  # {{{
             except:
                 pass
 
+        in_tag_browser_col = self.FIELD_MAP['in_tag_browser']
+        for r in self.iterall():
+            r[in_tag_browser_col] = None
+
         self._map = [i[0] for i in self._data if i is not None]
         if field is not None:
             self.sort(field, ascending)
