@@ -43,6 +43,14 @@ def index_theme(name, inherits=''):
     return '\n'.join(lines)
 
 
+def safe_link(src, dest):
+    try:
+        os.link(src, dest)
+    except FileExistsError:
+        os.remove(dest)
+        os.link(src, dest)
+
+
 def compile_icon_dir_as_themes(
     path_to_dir, output_path, theme_name='calibre-default', inherits='',
     for_theme='any', prefix='/icons',
@@ -83,7 +91,7 @@ def compile_icon_dir_as_themes(
             if ext.lower() not in ('.png',):
                 if image_name == 'metadata.json':
                     dest = theme_dir, dest_name
-                    os.link(image_path, os.path.join(tdir, *dest))
+                    safe_link(image_path, os.path.join(tdir, *dest))
                     file('/'.join(dest))
                 return
             if base.endswith('-for-dark-theme'):
@@ -99,11 +107,7 @@ def compile_icon_dir_as_themes(
                     return
                 dest_name = dest_name.replace('-for-light-theme', '')
             dest = theme_dir, 'images', (rp + dest_name)
-            try:
-                os.link(image_path, os.path.join(tdir, *dest))
-            except FileExistsError:
-                os.remove(os.path.join(tdir, *dest))
-                os.link(image_path, os.path.join(tdir, *dest))
+            safe_link(image_path, os.path.join(tdir, *dest))
             file('/'.join(dest))
 
         for dirpath, dirnames, filenames in os.walk(path_to_dir):
