@@ -75,7 +75,7 @@ static PyMethodDef PyGUID_methods[] = {
 // }}}
 
 // Handle {{{
-typedef enum { NormalHandle, ModuleHandle, IconHandle } WinHandleType;
+typedef enum { NormalHandle, ModuleHandle, IconHandle, BitmapHandle } WinHandleType;
 
 typedef struct {
     PyObject_HEAD
@@ -94,6 +94,8 @@ Handle_close_(Handle *self) {
 				FreeLibrary((HMODULE)self->handle); break;
 			case IconHandle:
 				DestroyIcon((HICON)self->handle); break;
+            case BitmapHandle:
+                DeleteObject((HBITMAP)self->handle); break;
 		}
 		self->handle = NULL;
 	}
@@ -132,6 +134,8 @@ Handle_repr(Handle * self) {
 			name = "HMODULE"; break;
 		case IconHandle:
 			name = "HICON"; break;
+        case BitmapHandle:
+            name = "HBITMAP"; break;
 	}
 	return PyUnicode_FromFormat("<Win32 handle of type %s at: %p %V>", name, self->handle, self->associated_name, "");
 }
@@ -162,6 +166,7 @@ Handle_new(PyTypeObject *type, PyObject *args, PyObject *kwds) {
 		case NormalHandle:
 		case IconHandle:
 		case ModuleHandle:
+        case BitmapHandle:
 			break;
 		default:
 			PyErr_Format(PyExc_TypeError, "unknown handle type: %d", type);
@@ -978,7 +983,7 @@ write_file(PyObject *self, PyObject *args) {
     DWORD written = 0;
     BOOL ok;
     Py_BEGIN_ALLOW_THREADS
-    ok = WriteFile(handle, data + offset, size - offset, &written, NULL);
+    ok = WriteFile(handle, data + offset, (DWORD)(size - offset), &written, NULL);
     Py_END_ALLOW_THREADS
     if (!ok) return set_error_from_handle(args);
     return PyLong_FromUnsignedLong(written);
@@ -1099,39 +1104,48 @@ load_icons(PyObject *self, PyObject *args) {
 	return ans;
 }
 
-_COM_SMARTPTR_TYPEDEF(IImageList, __uuidof(IImageList));
-
-static HICON
-get_icon_at_index(int shilsize, int index) {
-	IImageListPtr spiml;
-	HRESULT hr = SHGetImageList(shilsize, IID_PPV_ARGS(&spiml));
-	HICON hico = NULL;
-	if (SUCCEEDED(hr)) spiml->GetIcon(index, ILD_TRANSPARENT, &hico);
-	return hico;
-}
-
 static PyObject*
 get_icon_for_file(PyObject *self, PyObject *args) {
 	wchar_raii path;
-	if (!PyArg_ParseTuple(args, "O&", py_to_wchar_no_none, &path)) return NULL;
+    long width = 256, height = 256;
+	if (!PyArg_ParseTuple(args, "O&|ll", py_to_wchar_no_none, &path, &width, &height)) return NULL;
 	scoped_com_initializer com;
 	if (!com.succeeded()) { PyErr_SetString(PyExc_OSError, "Failed to initialize COM"); return NULL; }
-	SHFILEINFO fi = {0};
-	DWORD_PTR res;
-	Py_BEGIN_ALLOW_THREADS
-	res = SHGetFileInfoW(path.ptr(), 0, &fi, sizeof(fi), SHGFI_SYSICONINDEX);
-	Py_END_ALLOW_THREADS
-	if (!res) return PyErr_SetExcFromWindowsErrWithFilenameObject(PyExc_OSError, ERROR_RESOURCE_TYPE_NOT_FOUND, PyTuple_GET_ITEM(args, 0));
-	HICON icon;
-#define R(shil) { \
-	Py_BEGIN_ALLOW_THREADS \
-	icon = get_icon_at_index(SHIL_JUMBO, fi.iIcon); \
-	Py_END_ALLOW_THREADS \
-	if (icon) return (PyObject*)Handle_create(icon, IconHandle); \
-}
-	R(SHIL_JUMBO); R(SHIL_EXTRALARGE); R(SHIL_LARGE); R(SHIL_SYSSMALL); R(SHIL_SMALL);
-#undef R
-	return PyErr_SetExcFromWindowsErrWithFilenameObject(PyExc_OSError, ERROR_RESOURCE_TYPE_NOT_FOUND, PyTuple_GET_ITEM(args, 0));
+    IShellItemImageFactory *pImageFactory;
+    HRESULT hr;
+    Py_BEGIN_ALLOW_THREADS
+    hr = SHCreateItemFromParsingName(path.ptr(), NULL, IID_PPV_ARGS(&pImageFactory));
+    Py_END_ALLOW_THREADS
+    if (!SUCCEEDED(hr)) {
+        return error_from_hresult(hr, "Failed to create Shell Item from path");
+    }
+    SIZE size = { width, height };
+    HBITMAP hbmp;
+    Py_BEGIN_ALLOW_THREADS
+    hr = pImageFactory->GetImage(size, SIIGBF_BIGGERSIZEOK | SIIGBF_SCALEUP | SIIGBF_ICONONLY, &hbmp);
+    pImageFactory->Release();
+    Py_END_ALLOW_THREADS
+    if (!SUCCEEDED(hr)) {
+        return error_from_hresult(hr, "Failed to get image from shell item");
+    }
+    BITMAP bmp;
+    if (GetObject(hbmp, sizeof( BITMAP ), &bmp) == 0) {
+        DeleteObject(hbmp);
+        PyErr_SetString(PyExc_OSError, "Failed to load bitmap data from HBITMAP");
+        return NULL;
+    }
+    HBITMAP hbmMask = CreateCompatibleBitmap(GetDC(NULL), bmp.bmWidth, bmp.bmHeight);
+    ICONINFO ii = {0};
+    ii.fIcon    = TRUE;
+    ii.hbmColor = hbmp;
+    ii.hbmMask  = hbmMask;
+    HICON hIcon = CreateIconIndirect(&ii);
+    DeleteObject(hbmp); DeleteObject(hbmMask);
+    if (hIcon == NULL) {
+        PyErr_SetFromWindowsErr(GetLastError());
+        return NULL;
+    }
+	return (PyObject*)Handle_create(hIcon, IconHandle);
 } // }}}
 
 // Boilerplate  {{{
@@ -1463,6 +1477,7 @@ exec_module(PyObject *m) {
     A(NormalHandle);
     A(ModuleHandle);
     A(IconHandle);
+    A(BitmapHandle);
 
 	A(KF_FLAG_DEFAULT);
 	A(KF_FLAG_FORCE_APP_DATA_REDIRECTION);
